@@ -81,7 +81,8 @@ class Instruction(namedtuple('Instruction', ('type', 'direction', 'target_idx'),
             InstructionType.BOND_PLUS: ('bond', 0),
             InstructionType.BOND_MINUS: ('bond', 1),
             InstructionType.SENSE: ('sensor', 0),
-            InstructionType.FLIP_FLOP: ('toggle', 0)}
+            InstructionType.FLIP_FLOP: ('toggle', 0),
+            InstructionType.PAUSE: ('debug', 0)}
         if self.type in special_case_dict:
             name, sub_type = special_case_dict[self.type]
         else:
@@ -179,8 +180,8 @@ class Waldo:
                 else:
                     lines.append(instr.export_str(waldo_idx=self.idx, posn=posn))
 
-        # Put the start instr line at the front and sort the remaining lines
-        return start_line + '\n' + '\n'.join(lines)
+        # Put the start instr line at the front
+        return '\n'.join([start_line, *lines])
 
     def trace_path(self, num_cols=10, num_rows=8):
         """Return a dict of position: directions representing paths this waldo visually traces.
